pub struct CacheWriter { /* private fields */ }Expand description
Writes events to on-disk binary cache format.
Implementations
Sourceimpl CacheWriter
impl CacheWriter
Sourcepub fn push_event(&mut self, event: &Event)
pub fn push_event(&mut self, event: &Event)
Add one event to the writer buffer.
Sourcepub fn write_to_file(&self, path: &Path) -> Result<CacheStats>
pub fn write_to_file(&self, path: &Path) -> Result<CacheStats>
Encode all buffered events and write them to path.
Parent directories are created automatically.
Errors
Returns an error if encoding or file I/O fails.
Sourcepub fn append_incremental(
existing: &Path,
new_events: &[Event],
) -> Result<CacheStats>
pub fn append_incremental( existing: &Path, new_events: &[Event], ) -> Result<CacheStats>
Append new_events to an existing cache file, rewriting the whole file.
If the cache file does not exist, this behaves like a normal write with
just new_events.
Errors
Returns an error if decoding existing data, encoding, or file I/O fails.