extract_snapshot_payload

Function extract_snapshot_payload 

pub fn extract_snapshot_payload(event: &Event) -> Result<SnapshotPayload>
Extract and deserialize the SnapshotPayload from an item.snapshot event.

Errors

Returns an error if the event is not a snapshot type or if the payload cannot be deserialized.