pub fn load_project_config(project_root: &Path) -> Result<ProjectConfig>Expand description
Load project-level configuration from .bones/config.toml.
Errors
Returns an error if the file exists but cannot be read or parsed.
pub fn load_project_config(project_root: &Path) -> Result<ProjectConfig>Load project-level configuration from .bones/config.toml.
Returns an error if the file exists but cannot be read or parsed.