pub fn load_user_config() -> Result<UserConfig>Expand description
Load user-level configuration from <config-dir>/bones/config.toml.
Errors
Returns an error if the file exists but cannot be read or parsed.
pub fn load_user_config() -> Result<UserConfig>Load user-level configuration from <config-dir>/bones/config.toml.
Returns an error if the file exists but cannot be read or parsed.