pub enum HashError {
HashMismatch {
stored: String,
expected: String,
},
UnknownParent {
event_hash: String,
parent_hash: String,
},
Compute(WriteError),
}Expand description
Errors from DAG hash verification.
Variants
HashMismatch
The stored event hash does not match the recomputed hash.
Fields
UnknownParent
A parent hash referenced by an event is not found in the event set.
Fields
Compute(WriteError)
Failed to compute the hash of an event.
Implementations