pub fn get_dependencies(
conn: &Connection,
item_id: &str,
) -> Result<Vec<QueryDependency>>Expand description
Get items that a given item depends on (its blockers).
Errors
Returns an error if the query fails.
pub fn get_dependencies(
conn: &Connection,
item_id: &str,
) -> Result<Vec<QueryDependency>>Get items that a given item depends on (its blockers).
Returns an error if the query fails.