pub struct ProjectStats {
pub by_state: HashMap<String, usize>,
pub by_kind: HashMap<String, usize>,
pub by_urgency: HashMap<String, usize>,
pub events_by_type: HashMap<String, usize>,
pub events_by_agent: HashMap<String, usize>,
}Expand description
Aggregate counters for project-level stats used by reporting commands.
Fields
by_state: HashMap<String, usize>Open items by state (excluding deleted).
by_kind: HashMap<String, usize>Open items by kind (excluding deleted).
by_urgency: HashMap<String, usize>Open items by urgency (excluding deleted).
events_by_type: HashMap<String, usize>Events by type from the projected event tracker (empty when unavailable).
events_by_agent: HashMap<String, usize>Events by agent from the projected event tracker (empty when unavailable).