pub struct SnapshotData {
pub state: Value,
pub extra: BTreeMap<String, Value>,
}Expand description
Payload for item.snapshot.
Lattice-compacted full state for a completed item. Replaces the event history with a single snapshot event during log compaction.
Fields
state: ValueThe full compacted state of the work item as a JSON object.
extra: BTreeMap<String, Value>Unknown fields preserved for forward compatibility.