pub struct MergeResult {
pub events: Vec<Event>,
pub new_local: usize,
pub new_remote: usize,
pub duplicates_skipped: usize,
}Expand description
The result of merging two event sets.
Contains the merged, deduplicated, deterministically sorted events.
Fields
events: Vec<Event>Merged events, sorted by (wall_ts_us, agent, event_hash).
new_local: usizeNumber of unique events present on remote but not in local.
new_remote: usizeNumber of unique events present on local but not in remote.
duplicates_skipped: usizeNumber of duplicate input events skipped during deduplication.