pub fn verify_lattice_join(
original_events: &[Event],
snapshot_event: &Event,
) -> Result<bool>Expand description
Verify lattice join property: merge(original, snapshot) == original.
If compaction is correct, the snapshot is the join of all events, so merging the snapshot with the original state should produce identical state (idempotency of join with self’s join).
Errors
Returns an error if the snapshot event cannot be deserialized.