pub fn resolve_config(
project_root: &Path,
cli_json: bool,
) -> Result<EffectiveConfig>Expand description
Resolve the effective configuration by merging project, user, CLI, and environment settings.
Errors
Returns an error if loading project or user configuration fails.