pub trait Merge {
// Required method
fn merge(&mut self, other: Self);
}Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Merge for EpochPhase
impl Merge for Timestamp
impl<T> Merge for Lww<T>
impl<T: Eq + Hash + Clone> Merge for GSet<T>
impl<T: Eq + Hash + Clone> Merge for OrSet<T>
Merge implementation for OR-Set.
The merge is a union of both the element sets and the tombstone sets. This satisfies semilattice laws because set union is commutative, associative, and idempotent.
After merge, an element is present iff it has at least one add-tag not covered by a tombstone entry.