pub fn is_blocked<S: BuildHasher>(
item_id: &str,
states: &HashMap<String, WorkItemState, S>,
) -> boolExpand description
Check if an item is blocked given a map of states.
Returns false if the item is not present in states.
pub fn is_blocked<S: BuildHasher>(
item_id: &str,
states: &HashMap<String, WorkItemState, S>,
) -> boolCheck if an item is blocked given a map of states.
Returns false if the item is not present in states.