Module prolly

Module prolly 

Prolly Tree: content-defined chunked Merkle tree for efficient O(log N) diff.

Events are keyed by (item_id, wall_ts_us), sorted, then split into chunks using a rolling hash (Gear hash) for content-defined boundaries. A balanced Merkle tree is built over the chunks so that two replicas can diff in O(log N) time by comparing hashes top-down.

Structs

Hash
32-byte BLAKE3 hash used as a node/chunk identity.
ProllyTree
Content-addressed Prolly Tree over a set of events.

Enums

ProllyNode
A Prolly Tree node — either a leaf chunk of events or an interior node pointing to children.